@@ -2,9 +2,9 @@
 #' @description GO enrichment analysis and bar plot (None/Exist Reference Genome).
 #' @author benben-miao
 #'
-#' @return Table: GO enrichment analysis and bar plot (None/Exist Reference Genome).
-#' @param go_anno Dataframe: include columns (id, biological_process, cellular_component, molecular_function),  symbol ";" split GO terms.
-#' @param go_deg_fc Dataframe: include columns (id, log2FC).
+#' @return Plot: GO enrichment analysis and bar plot (None/Exist Reference Genome).
+#' @param go_anno Dataframe: GO and KEGG annotation of background genes (1st-col: Genes, 2nd-col: biological_process, 3rd-col: cellular_component, 4th-col: molecular_function, 5th-col: kegg_pathway).
+#' @param degs_list Dataframe: degs list.
 #' @param padjust_method Character: P-value adjust to Q-value. Default: "fdr" (false discovery rate), options: "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none".
 #' @param pvalue_cutoff Numeric: P-value cutoff. Recommend: small than 0.05.
 #' @param qvalue_cutoff Numeric: Q-value cutoff. Recommend: small than 0.05.
@@ -29,32 +29,26 @@
 #' library(TOmicsVis)
 #'
 #' # 2. Use example dataset
-#' data(go_anno)
-#' head(go_anno)
-#'
-#' data(go_deg_fc)
-#' head(go_deg_fc)
+#' data(gene_go_kegg)
+#' head(gene_go_kegg)
 #'
 #' # 3. Default parameters
-#' go_enrich_bar(go_anno, go_deg_fc)
+#' go_enrich_bar(gene_go_kegg[,-5], gene_go_kegg[100:200,1])
 #'
 #' # 4. Set padjust_method = "BH"
-#' go_enrich_bar(go_anno, go_deg_fc, padjust_method = "BH")
+#' go_enrich_bar(gene_go_kegg[,-5], gene_go_kegg[100:200,1], padjust_method = "BH")
 #'
 #' # 5. Set category_num = 10
-#' go_enrich_bar(go_anno, go_deg_fc, category_num = 10)
+#' go_enrich_bar(gene_go_kegg[,-5], gene_go_kegg[100:200,1], category_num = 10)
 #'
-#' # 6. Set low_color = "#ff8800ff", high_color = "#008888ff"
-#' go_enrich_bar(go_anno, go_deg_fc, low_color = "#ff8800ff", high_color = "#008888ff")
-#'
-#' # 7. Set ggTheme = "theme_bw"
-#' go_enrich_bar(go_anno, go_deg_fc, ggTheme = "theme_bw")
+#' # 6. Set ggTheme = "theme_bw"
+#' go_enrich_bar(gene_go_kegg[,-5], gene_go_kegg[100:200,1], ggTheme = "theme_bw")
 #'
 go_enrich_bar <- function(go_anno,
-										 go_deg_fc,
+										 degs_list,
 										 padjust_method = "fdr",
-										 pvalue_cutoff = 0.50,
-										 qvalue_cutoff = 0.50,
+										 pvalue_cutoff = 0.05,
+										 qvalue_cutoff = 0.05,
 										 sign_by = "p.adjust",
 										 category_num = 30,
 										 font_size = 12,
@@ -76,14 +70,14 @@ go_enrich_bar <- function(go_anno,
 
 	# -> 3. Data
 	gene_go <- go_anno
-	deg_fc <- go_deg_fc
+	degs_list <- degs_list
 
-	deg_fc["log2FC"] <- 2^(deg_fc["log2FC"])
-	deg_list <- with(deg_fc, setNames(log2FC, id))
+	# deg_fc["log2FC"] <- 2^(deg_fc["log2FC"])
+	# deg_list <- with(deg_fc, setNames(log2FC, id))
 
 	gene_go1 <- melt(gene_go,
 									 na.rm = FALSE,
-									 id.vars = c("id"),
+									 id.vars = c("Genes"),
 									 measure.vars = c("biological_process", "cellular_component", "molecular_function"),
 									 variable.name = "ontology",
 									 value.name = "term",
@@ -105,13 +99,13 @@ go_enrich_bar <- function(go_anno,
 	gene_go4["description"] <- gsub(")", "", gene_go4$description)
 	gene_go4["ontology"] <- gsub("_", " ", gene_go4$ontology)
 
-	gene_go5 <- data.frame(gene_go4["id"],
+	gene_go5 <- data.frame(gene_go4["Genes"],
 												 gene_go4["term"],
 												 gene_go4["ontology"],
 												 gene_go4["description"]
 	)
 
-	enrich_results <- enricher(gene = deg_fc[[1]],
+	enrich_results <- enricher(gene = degs_list,
 														 TERM2GENE = data.frame(gene_go5[,2],gene_go5[,1]),
 														 TERM2NAME = data.frame(gene_go5[,2],gene_go5[,4]),
 														 pvalueCutoff = pvalue_cutoff,
