@@ -3,10 +3,10 @@
 #' @author benben-miao
 #'
 #' @return Plot: MversusA plot for visualizing differentially expressed genes.
-#' @param data Dataframe: include columns (Genes, baseMean, Log2FoldChange, Padj), rows (Genes).
-#' @param foldchange Numeric: fold change value. Default: 2.00, min: 0.00, max: null.
+#' @param data Dataframe: differentially expressed genes (DEGs) stats 2 (1st-col: Gene, 2nd-col: baseMean, 3rd-col: Log2FoldChange, 4th-col: FDR).
+#' @param foldchange Numeric: fold change value. Default: 1.0, min: 0.0, max: null.
 #' @param fdr_value Numeric: false discovery rate. Default: 0.05, min: 0.00, max: 1.00.
-#' @param point_size Numeric: point size. Default: 0.50, min: 0.00, max: null.
+#' @param point_size Numeric: point size. Default: 1.0, min: 0.0, max: null.
 #' @param color_up Character: up-regulated genes color (color name or hex value). Default: "#FF0000".
 #' @param color_down Character: down-regulated genes color (color name or hex value). Default: "#008800".
 #' @param color_alpha Numeric: point color alpha. Default: 0.50, min: 0.00, max: 1.00.
@@ -14,10 +14,10 @@
 #' @param top_num Numeric: top genes number. Default: 20, min: 0, max: null.
 #' @param label_size Numeric: label font size. Default: 8.00, min: 0.00, max: null.
 #' @param label_box Logical: add box to label. Default: TRUE, options: TRUE, FALSE.
-#' @param title Character: plot title. Default: "Group1 -versus- Group2".
+#' @param title Character: plot title. Default: "CT-vs-Trait1".
 #' @param xlab Character: x label. Default: "Log2 mean expression".
 #' @param ylab Character: y label. Default: "Log2 fold change".
-#' @param ggTheme Character: ggplot2 themes. Default: "theme_minimal", options: "theme_default", "theme_bw", "theme_gray", "theme_light", "theme_linedraw", "theme_dark", "theme_minimal", "theme_classic", "theme_void"
+#' @param ggTheme Character: ggplot2 themes. Default: "theme_light", options: "theme_default", "theme_bw", "theme_gray", "theme_light", "theme_linedraw", "theme_dark", "theme_minimal", "theme_classic", "theme_void"
 #'
 #' @import ggplot2
 #' @import ggsci
@@ -29,21 +29,22 @@
 #' library(TOmicsVis)
 #'
 #' # 2. Use example dataset
-#' data(deg_data2)
+#' data(degs_stats2)
+#' head(degs_stats2)
 #'
 #' # 3. Default parameters
-#' ma_plot(deg_data2)
+#' ma_plot(degs_stats2)
 #'
 #' # 4. Set color_up = "#FF8800"
-#' ma_plot(deg_data2, color_up = "#FF8800")
+#' ma_plot(degs_stats2, color_up = "#FF8800")
 #'
-#' # 5. Set color_alpha = 0.30
-#' ma_plot(deg_data2, color_alpha = 0.30)
+#' # 5. Set top_num = 10
+#' ma_plot(degs_stats2, top_num = 10)
 #'
 ma_plot <- function(data,
-										foldchange = 2.00,
+										foldchange = 1.0,
 										fdr_value = 0.05,
-										point_size = 0.50,
+										point_size = 3.0,
 										color_up = "#FF0000",
 										color_down = "#008800",
 										color_alpha = 0.50,
@@ -51,10 +52,10 @@ ma_plot <- function(data,
 										top_num = 20,
 										label_size = 8.00,
 										label_box = TRUE,
-										title = "Group1 -versus- Group2",
+										title = "CT-vs-LT12",
 										xlab = "Log2 mean expression",
 										ylab = "Log2 fold change",
-										ggTheme = "theme_minimal"
+										ggTheme = "theme_light"
 										){
 
 	# -> 2. Data Operation
